@@ -16,6 +16,7 @@ from honeybee.typing import float_in_range, float_positive
 from honeybee.config import folders
 
 from ladybug_geometry.geometry2d.pointvector import Vector2D, Point2D
+from ladybug.futil import preparedir
 
 import math
 import os
@@ -472,13 +473,8 @@ class Model(_BaseGeometry):
 
         return models
     
-    def to_geojson(self, location, point=Point2D(0, 0), folder=None, tolerance=0.01):
-        """Convert Dragonfly Model to a geoJSON of buildings footprints.
-
-        This geoJSON will be in a format that is compatible with the URBANopt SDK,
-        including properties for floor_area, footprint_area, and detailed_model_filename,
-        which will align with the paths to OpenStudio model (.osm) files output
-        from honeybee Models translated to OSM.
+    def to_geojson_dict(self, location, point=Point2D(0, 0), folder=None, tolerance=0.01):
+        """Convert Dragonfly Model to a geoJSON-style Python dictionary.
 
         Args:
             location: A ladybug Location object possessing longitude and lattiude data.
@@ -486,28 +482,29 @@ class Model(_BaseGeometry):
                 within the space of a scene. The coordinates of this point are
                 expected to be in the units of this Model. (Default: (0, 0)).
             folder: Text for the full path to the folder where the OpenStudio
-                model files for each building are written. This is also the location
-                where the geojson will be written.
+                model files for each building are written. This will be used
+                to specify URBANopt detailed_model_filename keys for each feature
+                within the dictionary. If None, the honeybee default simulation
+                folder will be used (Default: None).
             tolerance: The minimum distance between points at which they are
                 not considered touching. Default: 0.01, suitable for objects
                 in meters.
-        
+
         Returns:
-            The path to a geoJSON file that contains polygons for all of the
-            Buildings within the dragonfly model along with their properties
-            (floor area, number of stories, etc.). The polygons will also possess
-            detailed_model_filename keys that align with where OpenStudio models
-            would be written, assuming the input folder matches that used to
-            export OpenStudio models.
+            A Python dictionary in a geoJSON style with each Building in the Model
+            as a separate feature.
         """
-        # set up the base dictionary for the geoJSON and default folder
-        geojson_dict = {'type': 'FeatureCollection', 'features': [], 'mappers': []}
+        # set the default simulation folder
         if folder is None:
             folder = folders.default_simulation_folder
         else:
             assert os.path.isdir(folder), \
                 'No such directory has been found on this machine: {}'.format(folder)
 
+        # set up the base dictionary for the geoJSON and default folder
+        geojson_dict = {'type': 'FeatureCollection', 'features': [], 'mappers': []}
+        geojson_dict['project'] = {'name': self.display_name, 'id': self.name}
+
         # ensure that the Model we are working with is in meters with a north_angle of 0
         model = self
         if self.north_angle != 0:
@@ -555,8 +552,50 @@ class Model(_BaseGeometry):
             # append the feature to the global dictionary
             geojson_dict['features'].append(feature_dict)
 
+        return geojson_dict
+
+    def to_geojson(self, location, point=Point2D(0, 0), folder=None, tolerance=0.01):
+        """Convert Dragonfly Model to a geoJSON of buildings footprints.
+
+        This geoJSON will be in a format that is compatible with the URBANopt SDK,
+        including properties for floor_area, footprint_area, and detailed_model_filename,
+        which will align with the paths to OpenStudio model (.osm) files output
+        from honeybee Models translated to OSM.
+
+        Args:
+            location: A ladybug Location object possessing longitude and lattiude data.
+            point: A ladybug_geometry Point2D for where the location object exists
+                within the space of a scene. The coordinates of this point are
+                expected to be in the units of this Model. (Default: (0, 0)).
+            folder: Text for the full path to the folder where the OpenStudio
+                model files for each building are written. This is also the location
+                where the geojson will be written. If None, the honeybee default
+                simulation folder will be used (Default: None).
+            tolerance: The minimum distance between points at which they are
+                not considered touching. Default: 0.01, suitable for objects
+                in meters.
+
+        Returns:
+            The path to a geoJSON file that contains polygons for all of the
+            Buildings within the dragonfly model along with their properties
+            (floor area, number of stories, etc.). The polygons will also possess
+            detailed_model_filename keys that align with where OpenStudio models
+            would be written, assuming the input folder matches that used to
+            export OpenStudio models.
+        """
+        # set the default simulation folder
+        if folder is None:
+            folder = folders.default_simulation_folder
+        else:
+            preparedir(folder, remove_content=False)
+
+        # get the geojson dictionary
+        geojson_dict = self.to_geojson_dict(location, point, folder, tolerance)
+
         # write out the dictionary to a geojson file
-        file_path = os.path.join(folder, '{}.geojson'.format(self.name))
+        project_folder = os.path.join(folder, self.name)
+        preparedir(project_folder, remove_content=False)
+        file_path = os.path.join(project_folder, '{}.geojson'.format(self.name))
         with open(file_path, 'w') as fp:
             json.dump(geojson_dict, fp, indent=4)
         return file_path
